@@ -5,15 +5,16 @@ import json
 import logging
 import warnings
 from pathlib import Path
+import time
 import datetime 
 from collections import OrderedDict
 
 import boto3
+from hdfs3 import HDFileSystem
 import gorilla
 import pymysql
-from slack import WebClient
-from slack.errors import SlackApiError
-
+from slack_sdk import WebClient
+from slack_sdk.errors import SlackApiError
 import numpy as np
 import tensorflow
 from tensorflow.keras.callbacks import CSVLogger
@@ -40,7 +41,7 @@ warnings.filterwarnings("ignore")
 
 class accuinsight(object):
     def __init__(self):
-        self.BucketInfo = None
+        self.StorageInfo = None
         self.target_name = None
         self.save_path = None
         self.endpoint = None
@@ -49,57 +50,89 @@ class accuinsight(object):
         self.channel_id = None
         self.message = None
 
-    def get_file(self, aws_json_file_name):
+    def get_file(self, storage_json_file_name):
         
         # meta file 저장하는 폴더 만들면, 이 경로는 수정돼야 함.
-        aws_info_json_path = os.path.join(ENV_JUPYTER_HOME_DIR, aws_json_file_name)
+        storage_info_json_path = os.path.join(ENV_JUPYTER_HOME_DIR, storage_json_file_name)
        
-        with open(aws_info_json_path) as jsonFile:
-            self.BucketInfo = json.load(jsonFile)
+        with open(storage_info_json_path) as jsonFile:
+            self.StorageInfo = json.load(jsonFile)
             
-        BUCKET_TYPE = self.BucketInfo['bucketType']
-        BUCKET_NAME = self.BucketInfo['bucketName']
-        FILE_PATH = self.BucketInfo['filePath']
-        FILE_NAME = self.BucketInfo['fileName']
-        #FILE_TYPE = self.BucketInfo['fileType']
-        #FILE_DELIM = self.BucketInfo['fileDelim']
-        ACCESS_KEY = self.BucketInfo['myAccessKey']
-        SECRET_KEY = self.BucketInfo['mySecretKey']
-        REGION = self.BucketInfo['region']
-        URL = self.BucketInfo['endpoint']
-        
         ## define the target name 
-        self.target_name = self.BucketInfo['target']
+        self.target_name = self.StorageInfo['target']
+    
+        if 'host' in self.StorageInfo.keys():    # HDFS
+            
+            ## path for saving data
+            save_dir = os.path.join(ENV_JUPYTER_HOME_DIR, 'data_from_hdfs')
+            if os.path.exists(save_dir) == False:
+                os.mkdir(save_dir)
+            else:
+                pass
+            
+            split_list = list(filter(None, self.StorageInfo['filePath'].split('/')))
+            
+            HOST = self.StorageInfo['host']
+            PORT = int(self.StorageInfo['port'])
+            FILE_PATH = self.StorageInfo['filePath']
+            FILE_DIR = '/'
+            for i in split_list[:len(split_list)-1]:
+                FILE_DIR = os.path.join(FILE_DIR, i)
+            FILE_NAME = split_list[-1]
+            
+            self.save_file_name = FILE_NAME.split('.')[0] + '_' + str(datetime.datetime.now().date()).replace('-', '') + '.' + FILE_NAME.split('.')[1]
+            self.save_path = os.path.join(save_dir, self.save_file_name)
+            self.endpoint = os.path.join('hdfs://', HOST, self.StorageInfo['port']) + FILE_PATH
+            
+            hdfs = HDFileSystem(host = HOST, port = PORT)
+            hdfs.ls(FILE_DIR)
 
-        ## path for saving data
-        save_dir = os.path.join(ENV_JUPYTER_HOME_DIR, 'data_from_AWS')
-        if os.path.exists(save_dir) == False:
-            os.mkdir(save_dir)
-        else:
-            pass
+            sys.stdout.write('%s %s %s' % ('Downloading file...', FILE_NAME, '\n'))
+            time.sleep(1)
+            hdfs.get(FILE_PATH, self.save_path)
+            logging.info(self.save_path)
         
-        self.save_file_name = FILE_NAME.split('.')[0] + '_' + str(datetime.datetime.now().date()).replace('-', '') + '.' + FILE_NAME.split('.')[1]
-        self.save_path = os.path.join(save_dir, self.save_file_name)
+        else:     # AWS-S3
+            BUCKET_TYPE = self.StorageInfo['bucketType']
+            BUCKET_NAME = self.StorageInfo['bucketName']
+            FILE_PATH = self.StorageInfo['filePath']
+            FILE_NAME = self.StorageInfo['fileName']
+            #FILE_TYPE = self.StorageInfo['fileType']
+            #FILE_DELIM = self.StorageInfo['fileDelim']
+            ACCESS_KEY = self.StorageInfo['myAccessKey']
+            SECRET_KEY = self.StorageInfo['mySecretKey']
+            REGION = self.StorageInfo['region']
+            URL = self.StorageInfo['endpoint']
 
-        # endpoint
-        pre_url = 'https://' + BUCKET_NAME + '.' + URL
-        self.endpoint = os.path.join(pre_url, FILE_PATH)
+            ## path for saving data
+            save_dir = os.path.join(ENV_JUPYTER_HOME_DIR, 'data_from_aws')
+            if os.path.exists(save_dir) == False:
+                os.mkdir(save_dir)
+            else:
+                pass
+        
+            self.save_file_name = FILE_NAME.split('.')[0] + '_' + str(datetime.datetime.now().date()).replace('-', '') + '.' + FILE_NAME.split('.')[1]
+            self.save_path = os.path.join(save_dir, self.save_file_name)
 
-        client = boto3.client(BUCKET_TYPE,
-                              aws_access_key_id=ACCESS_KEY,
-                              aws_secret_access_key=SECRET_KEY,
-                              region_name=REGION)
+            # endpoint
+            pre_url = 'https://' + BUCKET_NAME + '.' + URL
+            self.endpoint = os.path.join(pre_url, FILE_PATH)
 
-        transfer = boto3.s3.transfer.S3Transfer(client)
+            client = boto3.client(BUCKET_TYPE,
+                                  aws_access_key_id=ACCESS_KEY,
+                                  aws_secret_access_key=SECRET_KEY,
+                                  region_name=REGION)
 
-        progress = ProgressPercentage(client, BUCKET_NAME, FILE_PATH)
+            transfer = boto3.s3.transfer.S3Transfer(client)
 
-        sys.stdout.write('%s %s %s' % ('Downloading file...', FILE_NAME, '\n'))
-        transfer.download_file(BUCKET_NAME, FILE_PATH, self.save_path, callback=progress)
-        logging.info(self.save_path)
+            progress = ProgressPercentage(client, BUCKET_NAME, FILE_PATH)
+
+            sys.stdout.write('%s %s %s' % ('Downloading file...', FILE_NAME, '\n'))
+            transfer.download_file(BUCKET_NAME, FILE_PATH, self.save_path, callback=progress)
+            logging.info(self.save_path)
     
    # def get_feature_name(self):
-   #     fileType = self.BucketInfo['fileName'].split('.')[0]
+   #     fileType = self.StorageInfo['fileName'].split('.')[0]
    #     if fileType == 'json':
    #         with open(self.save_path) as jsonFile:
    #             json_data = json.load(jsonFile)
@@ -132,13 +165,6 @@ class accuinsight(object):
         thresholds = self.thresholds
         token = self.token
         channel_id = self.channel_id
-        
-        print('global variable')
-        print(message)
-        print(thresholds)
-        print(token)
-        print(channel_id)
-        
     
         if best_weights == True:
             best_weights_on = True
@@ -147,16 +173,12 @@ class accuinsight(object):
         if model_monitor == True:
             shap_on = True
             try:
-                feature_name = get.feature_name(self.save_path, self.BucketInfo, self.target_name)
+                feature_name = get.feature_name(self.save_path, self.StorageInfo, self.target_name)
             except:
-                feature_name = None      # when user did not using <get_file> function     
+                feature_name = None      # when user did not use <get_file> function
         else:
             shap_on = False
         run_id = None
-        
-        
-        
-#         print(feature_name)   ####################################################
 
         is_notebook = is_in_ipython()
         if is_notebook == True:
@@ -498,46 +520,26 @@ class accuinsight(object):
         gorilla.apply(gorilla.Patch(tensorflow.keras.Model, 'fit', fit, settings=settings))
 
     def _send_message(metric=None, current_value=None, message=None, thresholds=None, token=None, channel_id=None):
-    
-        
-        print('send_message function')
-        print(message)
-        print(thresholds)
-        print(token)
-        print(channel_id)
         
+        logger = logging.getLogger(__name__)
         
         if token is not None and channel_id is not None:
         
-        
-            print('pass_1')
-        
             if thresholds is not None:
-                
-                
-                print('pass_thresholds')
-                            
-                            
                 try:
                     if current_value >= thresholds:
                         msg = '[모델 학습 완료] ' + metric + '이 설정하신 thresolds: ' + str(thresholds) + '를 초과하였습니다.'
                         response = WebClient(token=token).chat_postMessage(channel=channel_id, text=msg)
                 except SlackApiError as e:
-                    assert e.response["error"]
+                    logger.error(f"Error message: {e}")
+                    
             elif message is not None:
-                
                 try:
-                    print('pass_message')
                     msg = message
                     response = WebClient(token=token).chat_postMessage(channel=channel_id, text=msg)
-                    print('response complete')
                 except SlackApiError as e:
-                    assert e.response["error"]
-                    print('message_error')
+                    logger.error(f"Error message: {e}")
         else:
-            
-            print('pass_else')
-            
             pass
 
     def _off_autolog():
